# MAT-clustering: Summarization Methods for Multiple Aspect Trajectory Data Mining \[MAT-Tools Framework\]
---

\[[Publication](#)\] \[[citation.bib](citation.bib)\] \[[GitHub](https://github.com/mat-analysis/mat-matclustering)\] \[[PyPi](https://pypi.org/project/mat-matclustering/)\]


The present application offers a tool, to support the user in the data mining task of multiple aspect trajectories, specifically for clustering its complex data. It integrates into a unique platform the fragmented approaches available for multiple aspects trajectories and in general for multidimensional sequence classification into a unique web-based and python library system. 

Created on Apr, 2024
Copyright (C) 2024, License GPL Version 3 or superior (see LICENSE file)

### Main Modules



### Installation

Install directly from PyPi repository, or, download from github. (python >= 3.7 required)

```bash
    pip install matclustering
```

### Citing

If you use `matclustering` please cite the following paper:

    Tarlis Tortelli Portela; Jonata Tyska Carvalho; Vania Bogorny. HiPerMovelets: high-performance movelet extraction for trajectory classification, International Journal of Geographical Information Science, 2022. DOI: 10.1080/13658816.2021.2018593.

[Bibtex](citation.bib):

```bash
@article{Portela2022,
    author = {Tarlis Tortelli Portela and Jonata Tyska Carvalho and Vania Bogorny},
    title = {HiPerMovelets: high-performance movelet extraction for trajectory classification},
    journal = {International Journal of Geographical Information Science},
    volume = {0},
    number = {0},
    pages = {1-25},
    year  = {2022},
    publisher = {Taylor & Francis},
    doi = {10.1080/13658816.2021.2018593},
    URL = {https://doi.org/10.1080/13658816.2021.2018593}
}
```

### Collaborate with us

Any contribution is welcome. This is an active project and if you would like to include your algorithm in `matclustering`, feel free to fork the project, open an issue and contact us.

Feel free to contribute in any form, such as scientific publications referencing `matclustering`, teaching material and workshop videos.

### Related packages

This package is part of _MAT-Tools Framework_ for Multiple Aspect Trajectory Data Mining, check the guide project:

- **[mat-tools](https://github.com/mat-analysis/mat-tools)**: Reference guide for MAT-Tools Framework repositories

And others:



### Change Log

This is a package under construction, see [CHANGELOG.md](./CHANGELOG.md)
